function channels = RGB2Channels (RGB, kernels)
% RGB2Channels : Takes an RGB image as input and produces an output volume
% where the planes correspond to different image channels - the first three
% correspond to Lab color channels

nchannels = 3 + length(kernels);

% Note that we use single precision to cut down on memory
channels = zeros(size(RGB,1), size(RGB,2), nchannels, 'single');

%% Convert to Lab
channels(:,:,1:3) = applycform (double(RGB)/255, makecform('srgb2lab'));

Ig = single(rgb2gray(RGB));

%% Apply kernels - note the abs which introduces an important non-linearity

for i = 4:nchannels
    channels(:,:,i) = abs(imfilter(Ig, kernels{i-3}));
end