function L = makeL(labels, radius, sigma)
% makeL : Make an approporiate L matrix given the input labels array

sz = 2*radius + 1;

% Produce array of immediate neighbors
neighbors = double(im2col(padarray(labels,[radius radius]), [sz sz]));

% construct an array of weights
[X, Y] = meshgrid(-radius:radius, -radius:radius);

weight = exp(-(X.^2 + Y.^2)/(sigma^2));

% Figure out the weight supplied by the each neighbor
neighbor_weights = bsxfun(@times, (neighbors > 0), weight(:));

% Normalize the weights so each column sums to 1
neighbor_weights = bsxfun(@times, neighbor_weights, 1./sum(neighbor_weights,1));

maxlabel = max(labels(:));

% Assign zero entries to some inoffensive value so the subsequenst call to
% sparse works out.
neighbors(neighbors == 0) = maxlabel + 1;

col_idx = repmat (1:numel(labels), size(neighbors,1), 1);

L = sparse (col_idx(:), neighbors(:), neighbor_weights(:));

% elide the last column - (maxlabel + 1)
L(:,end) = [];