function out = orientedGradients (channels, nangles, radius)
% orientedGradients : takes as input a k x nrows x ncols array and computes
% the sum of the absolute values of the oriented gradients.

nrows     = size(channels,1);
ncols     = size(channels,2);

% Preallocate output
out = zeros(nangles, nrows, ncols, 'single');

[x, y] = meshgrid(-radius:radius, -radius:radius);

% Figure out which pixels are inside the circle
circle_mask = double ( (x.^2 + y.^2) <= (radius*radius) );

% For each orientation
for i = 1:nangles
    
    angle = deg2rad( (i-1)*(180.0/nangles));
    
    c = cos(angle);
    s = sin(angle);
    
    %% Produce oriented edge template
    x2 = c*x - s*y;
    
    % Here we just use a sigmoid along the x direction
    template = ( x2 ./ sqrt(1 + x2.^2) ) .* circle_mask;
    
    % Normalize the sum to zero mean
    template = template - mean(template(:));
    
    % Normalize to unit norm
    template = template / norm(template(:));
    
    %% Compute gradients on all channels by convolving with the template
    grad = abs ( imfilter (channels, template, 'replicate') );
    
    %% Sum across all of the channels
    out(i,:,:) =  squeeze (sum(grad,3));
    
end
    